pub trait Unstick<T> {
type Target;
// Required method
fn unstick(self) -> (Self::Target, T);
}Expand description
This trait helps to remove an item element from sized array.
pub trait Unstick<T> {
type Target;
// Required method
fn unstick(self) -> (Self::Target, T);
}This trait helps to remove an item element from sized array.